@@ -1,5 +1,5 @@
 /*
- * "$Id: adminutil.c 5970 2006-09-19 20:11:08Z mike $"
+ * "$Id: adminutil.c 6262 2007-02-11 16:59:33Z mike $"
  *
  *   Administration utility API definitions for the Common UNIX Printing
  *   System (CUPS).
@@ -7,7 +7,7 @@
  *   MANY OF THE FUNCTIONS IN THIS HEADER ARE PRIVATE AND SUBJECT TO
  *   CHANGE AT ANY TIME.  USE AT YOUR OWN RISK.
  *
- *   Copyright 2001-2006 by Easy Software Products.
+ *   Copyright 2001-2007 by Easy Software Products.
  *
  *   These coded instructions, statements, and computer programs are the
  *   property of Easy Software Products and are protected by Federal
@@ -48,9 +48,12 @@
 #include "debug.h"
 #include <errno.h>
 #include <fcntl.h>
-#include <unistd.h>
 #include <sys/stat.h>
-#include <sys/wait.h>
+#ifdef WIN32
+#else
+#  include <unistd.h>
+#  include <sys/wait.h>
+#endif /* WIN32 */
 
 
 /*
@@ -243,7 +246,7 @@ cupsAdminCreateWindowsPPD(
       if ((ptr = strchr(line, ':')) == NULL)
       {
         snprintf(line, sizeof(line),
-	          _cupsLangString(language, _("Missing value on line %d!\n")),
+	          _cupsLangString(language, _("Missing value on line %d!")),
 		  linenum);
         _cupsSetError(IPP_DOCUMENT_FORMAT_ERROR, line);
 
@@ -262,7 +265,7 @@ cupsAdminCreateWindowsPPD(
       {
         snprintf(line, sizeof(line),
 	         _cupsLangString(language,
-		                 _("Missing double quote on line %d!\n")),
+		                 _("Missing double quote on line %d!")),
 	         linenum);
         _cupsSetError(IPP_DOCUMENT_FORMAT_ERROR, line);
 
@@ -281,7 +284,7 @@ cupsAdminCreateWindowsPPD(
       {
         snprintf(line, sizeof(line),
 	         _cupsLangString(language,
-		                 _("Bad option + choice on line %d!\n")),
+		                 _("Bad option + choice on line %d!")),
 	         linenum);
         _cupsSetError(IPP_DOCUMENT_FORMAT_ERROR, line);
 
@@ -324,6 +327,21 @@ cupsAdminCreateWindowsPPD(
   cupsFileClose(srcfp);
   unlink(src);
 
+  if (linenum == 0)
+  {
+    snprintf(line, sizeof(line),
+             _cupsLangString(language, _("Empty PPD file!")),
+             linenum);
+    _cupsSetError(IPP_DOCUMENT_FORMAT_ERROR, line);
+
+    cupsFileClose(dstfp);
+    unlink(buffer);
+
+    *buffer = '\0';
+
+    return (NULL);
+  }
+
  /*
   * Now add the CUPS-specific attributes and options...
   */
@@ -656,7 +674,7 @@ cupsAdminExportSamba(
   {
     snprintf(message, sizeof(message),
              _cupsLangString(language,
-        		     _("Unable to set Windows printer driver (%d)!\n")),
+        		     _("Unable to set Windows printer driver (%d)!")),
         		     status);
 
     _cupsSetError(IPP_INTERNAL_ERROR, message);
@@ -985,6 +1003,11 @@ _cupsAdminSetServerSettings(
 		wrote_root_location;	/* Wrote the / location? */
   int		indent;			/* Indentation */
   int		cupsd_num_settings;	/* New number of settings */
+  int		old_remote_printers,	/* Show remote printers */
+		old_share_printers,	/* Share local printers */
+		old_remote_admin,	/* Remote administration allowed? */
+		old_user_cancel_any,	/* Cancel-job policy set? */
+		old_debug_logging;	/* LogLevel debug set? */
   cups_option_t	*cupsd_settings,	/* New settings */
 		*setting;		/* Current setting */
   _cups_globals_t *cg = _cupsGlobals();	/* Global data */
@@ -1017,39 +1040,134 @@ _cupsAdminSetServerSettings(
   else
     return (0);
 
+ /*
+  * Get current settings...
+  */
+
+  if (!_cupsAdminGetServerSettings(http, &cupsd_num_settings,
+                                   &cupsd_settings))
+    return (0);
+
+  if ((val = cupsGetOption(CUPS_SERVER_DEBUG_LOGGING, cupsd_num_settings,
+                           cupsd_settings)) != NULL)
+    old_debug_logging = atoi(val);
+  else
+    old_debug_logging = 0;
+
+  if ((val = cupsGetOption(CUPS_SERVER_REMOTE_ADMIN, cupsd_num_settings,
+                           cupsd_settings)) != NULL)
+    old_remote_admin = atoi(val);
+  else
+    old_remote_admin = 0;
+
+  if ((val = cupsGetOption(CUPS_SERVER_REMOTE_PRINTERS, cupsd_num_settings,
+                           cupsd_settings)) != NULL)
+    old_remote_printers = atoi(val);
+  else
+    old_remote_printers = 1;
+
+  if ((val = cupsGetOption(CUPS_SERVER_SHARE_PRINTERS, cupsd_num_settings,
+                           cupsd_settings)) != NULL)
+    old_share_printers = atoi(val);
+  else
+    old_share_printers = 0;
+
+  if ((val = cupsGetOption(CUPS_SERVER_USER_CANCEL_ANY, cupsd_num_settings,
+                           cupsd_settings)) != NULL)
+    old_user_cancel_any = atoi(val);
+  else
+    old_user_cancel_any = 0;
+
+  cupsFreeOptions(cupsd_num_settings, cupsd_settings);
+
  /*
   * Get basic settings...
   */
 
   if ((val = cupsGetOption(CUPS_SERVER_DEBUG_LOGGING, num_settings,
                            settings)) != NULL)
+  {
     debug_logging = atoi(val);
+
+    if (debug_logging == old_debug_logging)
+    {
+     /*
+      * No change to this setting...
+      */
+
+      debug_logging = -1;
+    }
+  }
   else
-    debug_logging = 0;
+    debug_logging = -1;
 
   if ((val = cupsGetOption(CUPS_SERVER_REMOTE_ADMIN, num_settings,
                            settings)) != NULL)
+  {
     remote_admin = atoi(val);
+
+    if (remote_admin == old_remote_admin)
+    {
+     /*
+      * No change to this setting...
+      */
+
+      remote_admin = -1;
+    }
+  }
   else
-    remote_admin = 0;
+    remote_admin = -1;
 
   if ((val = cupsGetOption(CUPS_SERVER_REMOTE_PRINTERS, num_settings,
                            settings)) != NULL)
+  {
     remote_printers = atoi(val);
+
+    if (remote_printers == old_remote_printers)
+    {
+     /*
+      * No change to this setting...
+      */
+
+      remote_printers = -1;
+    }
+  }
   else
-    remote_printers = 1;
+    remote_printers = -1;
 
   if ((val = cupsGetOption(CUPS_SERVER_SHARE_PRINTERS, num_settings,
                            settings)) != NULL)
+  {
     share_printers = atoi(val);
+
+    if (share_printers == old_share_printers)
+    {
+     /*
+      * No change to this setting...
+      */
+
+      share_printers = -1;
+    }
+  }
   else
-    share_printers = 0;
+    share_printers = -1;
 
   if ((val = cupsGetOption(CUPS_SERVER_USER_CANCEL_ANY, num_settings,
                            settings)) != NULL)
+  {
     user_cancel_any = atoi(val);
+
+    if (user_cancel_any == old_user_cancel_any)
+    {
+     /*
+      * No change to this setting...
+      */
+
+      user_cancel_any = -1;
+    }
+  }
   else
-    user_cancel_any = 0;
+    user_cancel_any = -1;
 
  /*
   * Create a temporary file for the new cupsd.conf file...
@@ -1101,13 +1219,14 @@ _cupsAdminSetServerSettings(
 
   while (cupsFileGetConf(cupsd, line, sizeof(line), &value, &linenum))
   {
-    if (!strcasecmp(line, "Port") || !strcasecmp(line, "Listen"))
+    if ((!strcasecmp(line, "Port") || !strcasecmp(line, "Listen")) &&
+        (share_printers >= 0 || remote_admin >= 0))
     {
       if (!wrote_port_listen)
       {
         wrote_port_listen = 1;
 
-	if (share_printers || remote_admin)
+	if (share_printers > 0 || remote_admin > 0)
 	{
 	  cupsFilePuts(temp, "# Allow remote access\n");
 	  cupsFilePrintf(temp, "Port %d\n", server_port);
@@ -1125,26 +1244,30 @@ _cupsAdminSetServerSettings(
           cupsFilePuts(temp, "Listen " CUPS_DEFAULT_DOMAINSOCKET "\n");
 #endif /* CUPS_DEFAULT_DOMAINSOCKET */
       }
-      else if (value && value[0] == '/' &&
-               strcmp(CUPS_DEFAULT_DOMAINSOCKET, value))
+      else if (value && value[0] == '/'
+#ifdef CUPS_DEFAULT_DOMAINSOCKET
+               && strcmp(CUPS_DEFAULT_DOMAINSOCKET, value)
+#endif /* CUPS_DEFAULT_DOMAINSOCKET */
+               )
         cupsFilePrintf(temp, "Listen %s\n", value);
     }
-    else if (!strcasecmp(line, "Browsing") ||
-             !strcasecmp(line, "BrowseAddress") ||
-             !strcasecmp(line, "BrowseAllow") ||
-             !strcasecmp(line, "BrowseDeny") ||
-             !strcasecmp(line, "BrowseOrder"))
+    else if ((!strcasecmp(line, "Browsing") ||
+              !strcasecmp(line, "BrowseAddress") ||
+              !strcasecmp(line, "BrowseAllow") ||
+              !strcasecmp(line, "BrowseDeny") ||
+              !strcasecmp(line, "BrowseOrder")) &&
+	     (remote_printers >= 0 || share_printers >= 0))
     {
       if (!wrote_browsing)
       {
         wrote_browsing = 1;
 
-        if (remote_printers || share_printers)
+        if (remote_printers > 0 || share_printers > 0)
 	{
-	  if (remote_printers && share_printers)
+	  if (remote_printers > 0 && share_printers > 0)
 	    cupsFilePuts(temp,
 	                 "# Enable printer sharing and shared printers.\n");
-	  else if (remote_printers)
+	  else if (remote_printers > 0)
 	    cupsFilePuts(temp,
 	                 "# Show shared printers on the local network.\n");
 	  else
@@ -1154,10 +1277,10 @@ _cupsAdminSetServerSettings(
 	  cupsFilePuts(temp, "Browsing On\n");
 	  cupsFilePuts(temp, "BrowseOrder allow,deny\n");
 
-	  if (remote_printers)
+	  if (remote_printers > 0)
 	    cupsFilePuts(temp, "BrowseAllow @LOCAL\n");
 
-	  if (share_printers)
+	  if (share_printers > 0)
 	    cupsFilePuts(temp, "BrowseAddress @LOCAL\n");
         }
 	else
@@ -1168,7 +1291,7 @@ _cupsAdminSetServerSettings(
 	}
       }
     }
-    else if (!strcasecmp(line, "LogLevel"))
+    else if (!strcasecmp(line, "LogLevel") && debug_logging >= 0)
     {
       wrote_loglevel = 1;
 
@@ -1231,13 +1354,13 @@ _cupsAdminSetServerSettings(
     {
       in_location = 0;
       indent -= 2;
-      if (in_admin_location)
+      if (in_admin_location && remote_admin >= 0)
       {
 	wrote_admin_location = 1;
 
 	if (remote_admin)
           cupsFilePuts(temp, "  # Allow remote administration...\n");
-	else
+	else if (remote_admin == 0)
           cupsFilePuts(temp, "  # Restrict access to the admin pages...\n");
 
         cupsFilePuts(temp, "  Order allow,deny\n");
@@ -1247,7 +1370,7 @@ _cupsAdminSetServerSettings(
 	else
 	  cupsFilePuts(temp, "  Allow localhost\n");
       }
-      else if (in_conf_location)
+      else if (in_conf_location && remote_admin >= 0)
       {
 	wrote_conf_location = 1;
 
@@ -1265,23 +1388,23 @@ _cupsAdminSetServerSettings(
 	else
 	  cupsFilePuts(temp, "  Allow localhost\n");
       }
-      else if (in_root_location)
+      else if (in_root_location && (remote_admin >= 0 || share_printers >= 0))
       {
 	wrote_root_location = 1;
 
-	if (remote_admin && share_printers)
+	if (remote_admin > 0 && share_printers > 0)
           cupsFilePuts(temp, "  # Allow shared printing and remote "
 	                     "administration...\n");
-	else if (remote_admin)
+	else if (remote_admin > 0)
           cupsFilePuts(temp, "  # Allow remote administration...\n");
-	else if (share_printers)
+	else if (share_printers > 0)
           cupsFilePuts(temp, "  # Allow shared printing...\n");
 	else
           cupsFilePuts(temp, "  # Restrict access to the server...\n");
 
         cupsFilePuts(temp, "  Order allow,deny\n");
 
-	if (remote_admin || share_printers)
+	if (remote_admin > 0 || share_printers > 0)
 	  cupsFilePuts(temp, "  Allow @LOCAL\n");
 	else
 	  cupsFilePuts(temp, "  Allow localhost\n");
@@ -1304,7 +1427,7 @@ _cupsAdminSetServerSettings(
 
       indent += 2;
 
-      if (!strcasecmp(value, "cancel-job"))
+      if (!strcasecmp(value, "cancel-job") && user_cancel_any >= 0)
       {
        /*
 	* Don't write anything for this limit section...
@@ -1323,7 +1446,7 @@ _cupsAdminSetServerSettings(
 	  if (*valptr)
 	    *valptr++ = '\0';
 
-          if (!strcasecmp(value, "cancel-job"))
+          if (!strcasecmp(value, "cancel-job") && user_cancel_any >= 0)
 	  {
 	   /*
 	    * Write everything except for this definition...
@@ -1359,7 +1482,9 @@ _cupsAdminSetServerSettings(
 
       in_cancel_job = 0;
     }
-    else if ((in_admin_location || in_conf_location || in_root_location) &&
+    else if ((((in_admin_location || in_conf_location || in_root_location) &&
+               remote_admin >= 0) ||
+              (in_root_location && share_printers >= 0)) &&
              (!strcasecmp(line, "Allow") || !strcasecmp(line, "Deny") ||
 	      !strcasecmp(line, "Order")))
       continue;
@@ -1424,13 +1549,13 @@ _cupsAdminSetServerSettings(
   * Write any missing info...
   */
 
-  if (!wrote_browsing)
+  if (!wrote_browsing && (remote_printers >= 0 || share_printers >= 0))
   {
-    if (remote_printers || share_printers)
+    if (remote_printers > 0 || share_printers > 0)
     {
-      if (remote_printers && share_printers)
+      if (remote_printers > 0 && share_printers > 0)
 	cupsFilePuts(temp, "# Enable printer sharing and shared printers.\n");
-      else if (remote_printers)
+      else if (remote_printers > 0)
 	cupsFilePuts(temp, "# Show shared printers on the local network.\n");
       else
 	cupsFilePuts(temp, "# Share local printers on the local network.\n");
@@ -1438,10 +1563,10 @@ _cupsAdminSetServerSettings(
       cupsFilePuts(temp, "Browsing On\n");
       cupsFilePuts(temp, "BrowseOrder allow,deny\n");
 
-      if (remote_printers)
+      if (remote_printers > 0)
 	cupsFilePuts(temp, "BrowseAllow @LOCAL\n");
 
-      if (share_printers)
+      if (share_printers > 0)
 	cupsFilePuts(temp, "BrowseAddress @LOCAL\n");
     }
     else
@@ -1451,7 +1576,7 @@ _cupsAdminSetServerSettings(
     }
   }
 
-  if (!wrote_loglevel)
+  if (!wrote_loglevel && debug_logging >= 0)
   {
     if (debug_logging)
     {
@@ -1465,9 +1590,9 @@ _cupsAdminSetServerSettings(
     }
   }
 
-  if (!wrote_port_listen)
+  if (!wrote_port_listen && (share_printers >= 0 || remote_admin >= 0))
   {
-    if (share_printers || remote_admin)
+    if (share_printers > 0 || remote_admin > 0)
     {
       cupsFilePuts(temp, "# Allow remote access\n");
       cupsFilePrintf(temp, "Port %d\n", ippPort());
@@ -1485,14 +1610,14 @@ _cupsAdminSetServerSettings(
 #endif /* CUPS_DEFAULT_DOMAINSOCKET */
   }
 
-  if (!wrote_root_location)
+  if (!wrote_root_location && (remote_admin >= 0 || share_printers >= 0))
   {
-    if (remote_admin && share_printers)
+    if (remote_admin > 0 && share_printers > 0)
       cupsFilePuts(temp,
                    "# Allow shared printing and remote administration...\n");
-    else if (remote_admin)
+    else if (remote_admin > 0)
       cupsFilePuts(temp, "# Allow remote administration...\n");
-    else if (share_printers)
+    else if (share_printers > 0)
       cupsFilePuts(temp, "# Allow shared printing...\n");
     else
       cupsFilePuts(temp, "# Restrict access to the server...\n");
@@ -1500,7 +1625,7 @@ _cupsAdminSetServerSettings(
     cupsFilePuts(temp, "<Location />\n"
                        "  Order allow,deny\n");
 
-    if (remote_admin || share_printers)
+    if (remote_admin > 0 || share_printers > 0)
       cupsFilePuts(temp, "  Allow @LOCAL\n");
     else
       cupsFilePuts(temp, "  Allow localhost\n");
@@ -1508,7 +1633,7 @@ _cupsAdminSetServerSettings(
     cupsFilePuts(temp, "</Location>\n");
   }
 
-  if (!wrote_admin_location)
+  if (!wrote_admin_location && remote_admin >= 0)
   {
     if (remote_admin)
       cupsFilePuts(temp, "# Allow remote administration...\n");
@@ -1526,7 +1651,7 @@ _cupsAdminSetServerSettings(
     cupsFilePuts(temp, "</Location>\n");
   }
 
-  if (!wrote_conf_location)
+  if (!wrote_conf_location && remote_admin >= 0)
   {
     if (remote_admin)
       cupsFilePuts(temp,
@@ -1547,7 +1672,7 @@ _cupsAdminSetServerSettings(
     cupsFilePuts(temp, "</Location>\n");
   }
 
-  if (!wrote_policy)
+  if (!wrote_policy && user_cancel_any >= 0)
   {
     cupsFilePuts(temp, "<Policy default>\n"
                        "  # Job-related operations must be done by the owner "
@@ -1626,21 +1751,50 @@ _cupsAdminSetServerSettings(
     * Updated OK, add the basic settings...
     */
 
-    cupsd_num_settings = cupsAddOption(CUPS_SERVER_DEBUG_LOGGING,
-                                       debug_logging ? "1" : "0",
-				       cupsd_num_settings, &cupsd_settings);
-    cupsd_num_settings = cupsAddOption(CUPS_SERVER_REMOTE_ADMIN,
-                                       remote_admin ? "1" : "0",
-				       cupsd_num_settings, &cupsd_settings);
-    cupsd_num_settings = cupsAddOption(CUPS_SERVER_REMOTE_PRINTERS,
-                                       remote_printers ? "1" : "0",
-				       cupsd_num_settings, &cupsd_settings);
-    cupsd_num_settings = cupsAddOption(CUPS_SERVER_SHARE_PRINTERS,
-                                       share_printers ? "1" : "0",
-				       cupsd_num_settings, &cupsd_settings);
-    cupsd_num_settings = cupsAddOption(CUPS_SERVER_USER_CANCEL_ANY,
-                                       user_cancel_any ? "1" : "0",
-				       cupsd_num_settings, &cupsd_settings);
+    if (debug_logging >= 0)
+      cupsd_num_settings = cupsAddOption(CUPS_SERVER_DEBUG_LOGGING,
+                                	 debug_logging ? "1" : "0",
+					 cupsd_num_settings, &cupsd_settings);
+    else
+      cupsd_num_settings = cupsAddOption(CUPS_SERVER_DEBUG_LOGGING,
+                                	 old_debug_logging ? "1" : "0",
+					 cupsd_num_settings, &cupsd_settings);
+
+    if (remote_admin >= 0)
+      cupsd_num_settings = cupsAddOption(CUPS_SERVER_REMOTE_ADMIN,
+                                	 remote_admin ? "1" : "0",
+					 cupsd_num_settings, &cupsd_settings);
+    else
+      cupsd_num_settings = cupsAddOption(CUPS_SERVER_REMOTE_ADMIN,
+                                	 old_remote_admin ? "1" : "0",
+					 cupsd_num_settings, &cupsd_settings);
+
+    if (remote_printers >= 0)
+      cupsd_num_settings = cupsAddOption(CUPS_SERVER_REMOTE_PRINTERS,
+                                	 remote_printers ? "1" : "0",
+					 cupsd_num_settings, &cupsd_settings);
+    else
+      cupsd_num_settings = cupsAddOption(CUPS_SERVER_REMOTE_PRINTERS,
+                                	 old_remote_printers ? "1" : "0",
+					 cupsd_num_settings, &cupsd_settings);
+
+    if (share_printers >= 0)
+      cupsd_num_settings = cupsAddOption(CUPS_SERVER_SHARE_PRINTERS,
+                                	 share_printers ? "1" : "0",
+					 cupsd_num_settings, &cupsd_settings);
+    else
+      cupsd_num_settings = cupsAddOption(CUPS_SERVER_SHARE_PRINTERS,
+                                	 old_share_printers ? "1" : "0",
+					 cupsd_num_settings, &cupsd_settings);
+
+    if (user_cancel_any >= 0)
+      cupsd_num_settings = cupsAddOption(CUPS_SERVER_USER_CANCEL_ANY,
+                                	 user_cancel_any ? "1" : "0",
+					 cupsd_num_settings, &cupsd_settings);
+    else
+      cupsd_num_settings = cupsAddOption(CUPS_SERVER_USER_CANCEL_ANY,
+                                	 old_user_cancel_any ? "1" : "0",
+					 cupsd_num_settings, &cupsd_settings);
 
    /*
     * Save the new values...
@@ -1681,6 +1835,10 @@ do_samba_command(const char *command,	/* I - Command to run */
 		 const char *authfile,	/* I - Samba authentication file */
 		 FILE *logfile)		/* I - Optional log file */
 {
+#ifdef WIN32
+  return (1);				/* Always fail on Windows... */
+
+#else
   int		status;			/* Status of command */
   int		pid;			/* Process ID of child */
 
@@ -1739,6 +1897,7 @@ do_samba_command(const char *command,	/* I - Command to run */
     return (WEXITSTATUS(status));
   else
     return (-WTERMSIG(status));
+#endif /* WIN32 */
 }
 
 
@@ -1756,7 +1915,9 @@ get_cupsd_conf(
     int             *remote)		/* O - Remote file? */
 {
   int		fd;			/* Temporary file descriptor */
+#ifndef WIN32
   struct stat	info;			/* cupsd.conf file information */
+#endif /* WIN32 */
   http_status_t	status;			/* Status of getting cupsd.conf */
   char		host[HTTP_MAX_HOST];	/* Hostname for connection */
 
@@ -1773,6 +1934,7 @@ get_cupsd_conf(
   snprintf(name, namesize, "%s/cupsd.conf", cg->cups_serverroot);
   *remote = 0;
 
+#ifndef WIN32
   if (!strcasecmp(host, "localhost") && !access(name, R_OK))
   {
    /*
@@ -1799,6 +1961,7 @@ get_cupsd_conf(
       status = HTTP_OK;
   }
   else
+#endif /* !WIN32 */
   {
    /*
     * Read cupsd.conf via a HTTP GET request...
@@ -1965,5 +2128,5 @@ write_option(cups_file_t     *dstfp,	/* I - PPD file */
 
 
 /*
- * End of "$Id: adminutil.c 5970 2006-09-19 20:11:08Z mike $".
+ * End of "$Id: adminutil.c 6262 2007-02-11 16:59:33Z mike $".
  */
