@@ -1,9 +1,9 @@
 /*
- * "$Id: http-private.h 6111 2006-11-15 20:28:39Z mike $"
+ * "$Id: http-private.h 6188 2007-01-10 16:23:06Z mike $"
  *
  *   Private HTTP definitions for the Common UNIX Printing System (CUPS).
  *
- *   Copyright 1997-2005 by Easy Software Products, all rights reserved.
+ *   Copyright 1997-2007 by Easy Software Products, all rights reserved.
  *
  *   These coded instructions, statements, and computer programs are the
  *   property of Easy Software Products and are protected by Federal
@@ -138,21 +138,22 @@ extern const char *hstrerror(int error);
  * Some OS's don't have getifaddrs() and freeifaddrs()...
  */
 
-#  include <net/if.h>
-#  ifdef HAVE_GETIFADDRS
-#    include <ifaddrs.h>
-#  else
-#    include <sys/ioctl.h>
-#    ifdef HAVE_SYS_SOCKIO_H
-#      include <sys/sockio.h>
-#    endif /* HAVE_SYS_SOCKIO_H */
+#  ifndef WIN32
+#    include <net/if.h>
+#    ifdef HAVE_GETIFADDRS
+#      include <ifaddrs.h>
+#    else
+#      include <sys/ioctl.h>
+#      ifdef HAVE_SYS_SOCKIO_H
+#        include <sys/sockio.h>
+#      endif /* HAVE_SYS_SOCKIO_H */
 
-#  ifdef ifa_dstaddr
-#    undef ifa_dstaddr
-#  endif /* ifa_dstaddr */
-#  ifndef ifr_netmask
-#    define ifr_netmask ifr_addr
-#  endif /* !ifr_netmask */
+#      ifdef ifa_dstaddr
+#        undef ifa_dstaddr
+#      endif /* ifa_dstaddr */
+#      ifndef ifr_netmask
+#        define ifr_netmask ifr_addr
+#      endif /* !ifr_netmask */
 
 struct ifaddrs				/**** Interface Structure ****/
 {
@@ -170,21 +171,22 @@ struct ifaddrs				/**** Interface Structure ****/
   void			*ifa_data;	/* Interface statistics */
 };
 
-#  ifndef ifa_broadaddr
-#    define ifa_broadaddr ifa_ifu.ifu_broadaddr
-#  endif /* !ifa_broadaddr */
-#  ifndef ifa_dstaddr
-#    define ifa_dstaddr ifa_ifu.ifu_dstaddr
-#  endif /* !ifa_dstaddr */
+#      ifndef ifa_broadaddr
+#        define ifa_broadaddr ifa_ifu.ifu_broadaddr
+#      endif /* !ifa_broadaddr */
+#      ifndef ifa_dstaddr
+#        define ifa_dstaddr ifa_ifu.ifu_dstaddr
+#      endif /* !ifa_dstaddr */
 
 extern int	_cups_getifaddrs(struct ifaddrs **addrs);
-#    define getifaddrs _cups_getifaddrs
+#      define getifaddrs _cups_getifaddrs
 extern void	_cups_freeifaddrs(struct ifaddrs *addrs);
-#    define freeifaddrs _cups_freeifaddrs
-#  endif /* HAVE_GETIFADDRS */
+#      define freeifaddrs _cups_freeifaddrs
+#    endif /* HAVE_GETIFADDRS */
+#  endif /* !WIN32 */
 
 #endif /* !_CUPS_HTTP_PRIVATE_H_ */
 
 /*
- * End of "$Id: http-private.h 6111 2006-11-15 20:28:39Z mike $".
+ * End of "$Id: http-private.h 6188 2007-01-10 16:23:06Z mike $".
  */
