@@ -1,9 +1,9 @@
 /*
- * "$Id: dirsvc.c 5940 2006-09-11 18:30:09Z mike $"
+ * "$Id: dirsvc.c 6205 2007-01-22 22:04:43Z mike $"
  *
  *   Directory services routines for the Common UNIX Printing System (CUPS).
  *
- *   Copyright 1997-2006 by Easy Software Products, all rights reserved.
+ *   Copyright 1997-2007 by Easy Software Products, all rights reserved.
  *
  *   These coded instructions, statements, and computer programs are the
  *   property of Easy Software Products and are protected by Federal
@@ -159,6 +159,17 @@ cupsdLoadRemoteCache(void)
   time_t		now;		/* Current time */
 
 
+ /*
+  * Don't load the cache if the CUPS remote protocol is disabled...
+  */
+
+  if (!Browsing || !(BrowseRemoteProtocols & BROWSE_CUPS))
+  {
+    cupsdLogMessage(CUPSD_LOG_DEBUG,
+                    "cupsdLoadRemoteCache: Not loading remote cache.");
+    return;
+  }
+
  /*
   * Open the remote.cache file...
   */
@@ -1062,7 +1073,7 @@ cupsdStartPolling(void)
   * Don't do anything if we aren't polling...
   */
 
-  if (NumPolled == 0)
+  if (NumPolled == 0 || BrowseSocket < 0)
   {
     PollPipe         = -1;
     PollStatusBuffer = NULL;
@@ -3181,5 +3192,5 @@ slp_url_callback(
 
 
 /*
- * End of "$Id: dirsvc.c 5940 2006-09-11 18:30:09Z mike $".
+ * End of "$Id: dirsvc.c 6205 2007-01-22 22:04:43Z mike $".
  */
